@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ $form = null;
 $script_inline = '';
 
 // Construct table header.
-$header_form = ($data['popup_type'] === 'help_items') ? (new CForm())->cleanItems() : new CDiv();
+$header_form = ($data['popup_type'] === 'help_items') ? (new CForm()): new CDiv();
 $header_form->setId('generic-popup-form');
 
 // Add host group multiselect control.
@@ -127,7 +127,6 @@ if ($controls) {
 // Create form.
 if ($data['form']) {
 	$form = (new CForm())
-		->cleanItems()
 		->setName($data['form']['name'])
 		->setId($data['form']['id']);
 }
@@ -160,6 +159,7 @@ switch ($data['popup_type']) {
 	case 'roles':
 	case 'api_methods':
 	case 'dashboard':
+	case 'sysmaps':
 		foreach ($data['table_records'] as $item) {
 			$check_box = $data['multiselect']
 				? new CCheckBox('item['.$item['id'].']', $item['id'])
@@ -196,36 +196,46 @@ switch ($data['popup_type']) {
 				? new CCheckBox('item['.$user['userid'].']', $user['userid'])
 				: null;
 
-			$username = (new CLink($user['username']))
-				->setId('spanid'.$user['userid'])
-				->setAttribute('data-reference', $options['reference'])
-				->setAttribute('data-userid', $user['userid'])
-				->setAttribute('data-parentid', $options['parentid'])
-				->onClick('
-					addValue(this.dataset.reference, this.dataset.userid, this.dataset.parentid ?? null);
-					popup_generic.closePopup(event);
-				');
+			if (array_key_exists('_disabled', $user)) {
+				if ($data['multiselect']) {
+					$check_box->setChecked(1);
+					$check_box->setEnabled(false);
+				}
 
-			$table->addRow([$check_box, $username, $user['name'], $user['surname']]);
+				$table->addRow([$check_box, $user['username'], $user['name'], $user['surname']]);
+			}
+			else {
+				$username = (new CLink($user['username']))
+					->setId('spanid'.$user['userid'])
+					->setAttribute('data-reference', $options['reference'])
+					->setAttribute('data-userid', $user['userid'])
+					->setAttribute('data-parentid', $options['parentid'])
+					->onClick('
+						addValue(this.dataset.reference, this.dataset.userid, this.dataset.parentid ?? null);
+						popup_generic.closePopup(event);
+					');
 
-			$entry = [];
-			$srcfld1 = $options['srcfld1'];
-			if ($srcfld1 === 'userid') {
-				$entry['id'] = $user['userid'];
-			}
-			elseif ($srcfld1 === 'username') {
-				$entry['name'] = $user['username'];
-			}
+				$table->addRow([$check_box, $username, $user['name'], $user['surname']]);
 
-			$srcfld2 = $options['srcfld2'];
-			if ($srcfld2 === 'fullname') {
-				$entry['name'] = getUserFullname($user);
-			}
-			elseif (array_key_exists($srcfld2, $user)) {
-				$entry[$srcfld2] = $user[$srcfld2];
-			}
+				$entry = [];
+				$srcfld1 = $options['srcfld1'];
+				if ($srcfld1 === 'userid') {
+					$entry['id'] = $user['userid'];
+				}
+				elseif ($srcfld1 === 'username') {
+					$entry['name'] = $user['username'];
+				}
 
-			$user = $entry;
+				$srcfld2 = $options['srcfld2'];
+				if ($srcfld2 === 'fullname') {
+					$entry['name'] = getUserFullname($user);
+				}
+				elseif (array_key_exists($srcfld2, $user)) {
+					$entry[$srcfld2] = $user[$srcfld2];
+				}
+
+				$user = $entry;
+			}
 		}
 		unset($user);
 		break;
@@ -236,19 +246,29 @@ switch ($data['popup_type']) {
 				? new CCheckBox('item['.$item['usrgrpid'].']', $item['usrgrpid'])
 				: null;
 
-			$name = (new CLink($item['name']))
-				->setId('spanid'.$item['usrgrpid'])
-				->setAttribute('data-reference', $options['reference'])
-				->setAttribute('data-usrgrpid', $item['usrgrpid'])
-				->setAttribute('data-parentid', $options['parentid'])
-				->onClick('
-					addValue(this.dataset.reference, this.dataset.usrgrpid, this.dataset.parentid ?? null);
-					popup_generic.closePopup(event);
-				');
+			if (array_key_exists('_disabled', $item)) {
+				if ($data['multiselect']) {
+					$check_box->setChecked(1);
+					$check_box->setEnabled(false);
+				}
+
+				$name = $item['name'];
+			}
+			else {
+				$name = (new CLink($item['name']))
+					->setId('spanid'.$item['usrgrpid'])
+					->setAttribute('data-reference', $options['reference'])
+					->setAttribute('data-usrgrpid', $item['usrgrpid'])
+					->setAttribute('data-parentid', $options['parentid'])
+					->onClick('
+						addValue(this.dataset.reference, this.dataset.usrgrpid, this.dataset.parentid ?? null);
+						popup_generic.closePopup(event);
+					');
+
+				$item['id'] = $item['usrgrpid'];
+			}
 
 			$table->addRow([$check_box, $name]);
-
-			$item['id'] = $item['usrgrpid'];
 		}
 		unset($item);
 		break;
@@ -267,6 +287,14 @@ switch ($data['popup_type']) {
 				? new CCheckBox('item['.zbx_jsValue($trigger[$options['srcfld1']]).']', $trigger['triggerid'])
 				: null;
 
+			if (array_key_exists('_disabled', $trigger)) {
+				if ($data['multiselect']) {
+					$check_box->setChecked(1);
+					$check_box->setEnabled(false);
+				}
+				$description = new CLabel($trigger['description']);
+			}
+
 			if ($data['multiselect']) {
 				$description
 					->setAttribute('data-reference', $options['reference'])
@@ -337,50 +365,6 @@ switch ($data['popup_type']) {
 		unset($trigger);
 		break;
 
-	case 'sysmaps':
-		foreach ($data['table_records'] as $sysmap) {
-			if ($data['multiselect']) {
-				$check_box = new CCheckBox('item['.$sysmap['sysmapid'].']', $sysmap['sysmapid']);
-			}
-
-			$name = (new CLink($sysmap['name']))->setId('spanid'.$sysmap['sysmapid']);
-
-			if ($data['multiselect']) {
-				$name
-					->setAttribute('data-reference', $options['reference'])
-					->setAttribute('data-sysmapid', $sysmap['sysmapid'])
-					->setAttribute('data-parentid', $options['parentid'])
-					->onClick('
-						addValue(this.dataset.reference, this.dataset.sysmapid, this.dataset.parentid ?? null);
-						popup_generic.closePopup(event);
-					');
-			}
-			else {
-				$values = [];
-
-				if ($options['dstfld1'] !== '' && $options['srcfld1'] !== '') {
-					$values[$options['dstfld1']] = $sysmap[$options['srcfld1']];
-				}
-				if ($options['dstfld2'] !== '' && $options['srcfld2'] !== '') {
-					$values[$options['dstfld2']] = $sysmap[$options['srcfld2']];
-				}
-				if ($options['dstfld3'] !== '' && $options['srcfld3'] !== '') {
-					$values[$options['dstfld3']] = $sysmap[$options['srcfld3']];
-				}
-
-				$name
-					->setAttribute('data-dstfrm', $options['dstfrm'])
-					->setAttribute('data-values', json_encode($values))
-					->onClick('
-						addValues(this.dataset.dstfrm, JSON.parse(this.dataset.values));
-						popup_generic.closePopup(event);
-					');
-			}
-
-			$table->addRow([$data['multiselect'] ? $check_box : null, $name]);
-		}
-		break;
-
 	case 'help_items':
 		foreach ($data['table_records'] as $key => $item) {
 			$item['key'] = $key;
@@ -469,7 +453,7 @@ switch ($data['popup_type']) {
 				$host = reset($item['hosts']);
 				$item['hostname'] = $host['name'];
 
-				$description = new CLink($item['name']);
+				$description = (new CLink($item['name']))->addClass(ZBX_STYLE_WORDBREAK);
 				$item['name'] = $item['hostname'].NAME_DELIMITER.$item['name'];
 
 				$checkbox_key = is_numeric($item[$options['srcfld1']])
@@ -538,7 +522,7 @@ switch ($data['popup_type']) {
 		else {
 			foreach ($data['table_records'] as &$item) {
 				$host = reset($item['hosts']);
-				$item_pattern = array_key_exists('pattern', $item) ? $item['pattern'] : $item['itemid'];
+				$item_pattern = $options['patternselect'] ? $item['name'] : $item['itemid'];
 
 				$table->addRow([
 					$data['multiselect']
@@ -551,7 +535,8 @@ switch ($data['popup_type']) {
 						->onClick('
 							addValue(this.dataset.reference, this.dataset.pattern, this.dataset.parentid ?? null);
 							popup_generic.closePopup(event);
-						'),
+						')
+						->addClass(ZBX_STYLE_WORDBREAK),
 					(new CDiv($item['key_']))->addClass(ZBX_STYLE_WORDWRAP),
 					item_type2str($item['type']),
 					itemValueTypeString($item['value_type']),
@@ -575,6 +560,10 @@ switch ($data['popup_type']) {
 				];
 			}
 			unset($item);
+
+			if ($options['patternselect']) {
+				$data['table_records'] = array_column($data['table_records'], null, 'name');
+			}
 		}
 		break;
 
@@ -658,6 +647,7 @@ switch ($data['popup_type']) {
 		break;
 
 	case 'valuemaps':
+	case 'template_valuemaps':
 		foreach ($data['table_records'] as $valuemap) {
 			$name = [];
 			$check_box = $data['multiselect']
@@ -717,7 +707,7 @@ switch ($data['popup_type']) {
 				$mappings_table[] = new CDiv($mapping['newvalue']);
 			}
 
-			$hellip = (count($valuemap['mappings']) > 3) ? '&hellip;' : null;
+			$hellip = (count($valuemap['mappings']) > 3) ? HELLIP() : null;
 			$table->addRow([$check_box, $name, [
 				(new CDiv($mappings_table))->addClass(ZBX_STYLE_VALUEMAP_MAPPINGS_TABLE), $hellip
 			]]);
@@ -763,6 +753,72 @@ switch ($data['popup_type']) {
 			$table->addRow([$check_box, $name, $status_tag]);
 		}
 		break;
+
+	case 'actions':
+		foreach ($data['table_records'] as &$action) {
+			$check_box = $data['multiselect']
+				? new CCheckBox('item['.$action['actionid'].']', $action['actionid'])
+				: null;
+
+			$name = (new CLink($action['name']))
+				->setId('spanid'.$action['actionid'])
+				->setAttribute('data-reference', $options['reference'])
+				->setAttribute('data-actionid', $action['actionid'])
+				->setAttribute('data-parentid', $options['parentid'])
+				->onClick('
+					addValue(this.dataset.reference, this.dataset.actionid, this.dataset.parentid ?? null);
+					popup_generic.closePopup(event);
+				');
+
+			$table->addRow([$check_box, $name]);
+
+			$entry = [];
+
+			if ($options['srcfld1'] === 'actionid') {
+				$entry['id'] = $action['actionid'];
+			}
+
+			if ($options['srcfld2'] === 'name') {
+				$entry['name'] = $action['name'];
+			}
+
+			$action = $entry;
+		}
+		unset($action);
+		break;
+
+	case 'media_types':
+		foreach ($data['table_records'] as &$media_type) {
+			$check_box = $data['multiselect']
+				? new CCheckBox('item['.$media_type['mediatypeid'].']', $media_type['mediatypeid'])
+				: null;
+
+			$name = (new CLink($media_type['name']))
+				->setId('spanid'.$media_type['mediatypeid'])
+				->setAttribute('data-reference', $options['reference'])
+				->setAttribute('data-mediatypeid', $media_type['mediatypeid'])
+				->setAttribute('data-parentid', $options['parentid'])
+				->onClick('
+					addValue(this.dataset.reference, this.dataset.mediatypeid, this.dataset.parentid ?? null);
+					popup_generic.closePopup(event);
+				');
+
+			$table->addRow([$check_box, $name]);
+
+			$entry = [];
+
+			if ($options['srcfld1'] === 'mediatypeid') {
+				$entry['id'] = $media_type['mediatypeid'];
+			}
+
+			if ($options['srcfld2'] === 'name') {
+				$entry['name'] = $media_type['name'];
+			}
+
+			$media_type = $entry;
+		}
+		unset($media_type);
+		break;
 }
 
 // Add submit button at footer.
@@ -786,6 +842,7 @@ if ($data['multiselect'] && $form !== null) {
 
 // Types require results returned as array.
 $types = [
+	'actions',
 	'api_methods',
 	'dashboard',
 	'graphs',
@@ -796,13 +853,16 @@ $types = [
 	'template_groups',
 	'items',
 	'item_prototypes',
+	'media_types',
 	'proxies',
 	'roles',
 	'templates',
 	'users',
 	'usrgrp',
 	'sla',
-	'valuemaps'
+	'valuemaps',
+	'template_valuemaps',
+	'sysmaps'
 ];
 
 if (array_key_exists('table_records', $data) && ($data['multiselect'] || in_array($data['popup_type'], $types))) {
@@ -817,12 +877,11 @@ $output['script_inline'] = $this->readJsFile('popup.generic.js.php').
 	'});';
 
 if ($form) {
-	$form->addItem([
-		$table,
-		(new CInput('submit', 'submit'))
-			->addStyle('display: none;')
-			->removeId()
-	]);
+	// Enable form submitting on Enter.
+	$form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
+
+	$form->addItem($table);
+
 	$output['body'] = (new CDiv([$data['messages'], $form]))->toString();
 }
 else {
