@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -715,8 +715,10 @@ class CScreenProblem extends CScreenBase {
 	 * @param int    $problem['clock']            Timestamp of the current record.
 	 * @param int    $problem['symptom_count']    Problem symptom count.
 	 * @param bool   $nested                      True if this is a nested block.
+	 * @param bool   $has_checkboxes              True if this is block is represented in Problem view with checkboxes.
+	 *                                            It will add additional colspan for timeline breakpoint.
 	 */
-	public static function addTimelineBreakpoint(CTableInfo $table, $data, $problem, $nested): void {
+	public static function addTimelineBreakpoint(CTableInfo $table, $data, $problem, $nested, $has_checkboxes): void {
 		if ($data['sortorder'] === ZBX_SORT_UP) {
 			[$problem['clock'], $data['last_clock']] = [$data['last_clock'], $problem['clock']];
 		}
@@ -747,7 +749,6 @@ class CScreenProblem extends CScreenBase {
 		}
 
 		if ($breakpoint !== null) {
-
 			$colspan = 1;
 
 			if ($data['show_three_columns']) {
@@ -759,7 +760,7 @@ class CScreenProblem extends CScreenBase {
 				$colspan = 2;
 			}
 
-			if (!($table instanceof widgets\problems\includes\WidgetProblems)) {
+			if ($has_checkboxes) {
 				$colspan++;
 			}
 
@@ -844,7 +845,7 @@ class CScreenProblem extends CScreenBase {
 		$symptom_cause_eventids = [];
 		$cause_eventids_with_symptoms = [];
 		$do_causes_have_symptoms = false;
-		$symptom_data['problems'] = [];
+		$symptom_data = ['problems' => []];
 
 		if ($data['problems']) {
 			$triggers_hosts = getTriggersHostsList($data['triggers']);
@@ -893,67 +894,81 @@ class CScreenProblem extends CScreenBase {
 		}
 
 		if ($cause_eventids_with_symptoms) {
-			// Get all symptoms for given cause event IDs.
-			$symptom_data = self::getData([
-				'show_symptoms' => true,
-				'show_suppressed' => true,
-				'cause_eventid' => $cause_eventids_with_symptoms,
-				'show' => $this->data['filter']['show'],
-				'details' => $this->data['filter']['details'],
-				'show_opdata' => $this->data['filter']['show_opdata']
-			], ZBX_PROBLEM_SYMPTOM_LIMIT, true);
-
-			if ($symptom_data['problems']) {
-				$symptom_data = self::sortData($symptom_data, ZBX_PROBLEM_SYMPTOM_LIMIT, $this->data['sort'],
-					$this->data['sortorder']
-				);
-
-				// Filter does not matter.
-				$symptom_data = self::makeData($symptom_data, [
+			foreach ($cause_eventids_with_symptoms as $cause_eventid) {
+				// Get all symptoms for given cause event ID.
+				$_symptom_data = self::getData([
+					'show_symptoms' => true,
+					'show_suppressed' => true,
+					'cause_eventid' => $cause_eventid,
 					'show' => $this->data['filter']['show'],
 					'details' => $this->data['filter']['details'],
 					'show_opdata' => $this->data['filter']['show_opdata']
-				], true);
+				], ZBX_PROBLEM_SYMPTOM_LIMIT, true);
 
-				$data['users'] += $symptom_data['users'];
-				$data['correlations'] += $symptom_data['correlations'];
+				if ($_symptom_data['problems']) {
+					$_symptom_data = self::sortData($_symptom_data, ZBX_PROBLEM_SYMPTOM_LIMIT, $this->data['sort'],
+						$this->data['sortorder']
+					);
 
-				foreach ($symptom_data['actions'] as $key => $actions) {
-					$data['actions'][$key] += $actions;
-				}
+					/*
+					 * Since getData returns +1 more in order to show the "+" sign for paging or sortData should not cut
+					 * off any excess problems, in order to display actual limit of symptoms, one more slice is
+					 * necessary.
+					 */
+					$_symptom_data['problems'] = array_slice($_symptom_data['problems'], 0, ZBX_PROBLEM_SYMPTOM_LIMIT,
+						true
+					);
 
-				if ($symptom_data['triggers']) {
-					$triggerids = array_keys($symptom_data['triggers']);
+					// Filter does not matter.
+					$_symptom_data = self::makeData($_symptom_data, [
+						'show' => $this->data['filter']['show'],
+						'details' => $this->data['filter']['details'],
+						'show_opdata' => $this->data['filter']['show_opdata']
+					], true);
 
-					$db_triggers = API::Trigger()->get([
-						'output' => [],
-						'selectDependencies' => ['triggerid'],
-						'triggerids' => $triggerids,
-						'preservekeys' => true
-					]);
+					$data['users'] += $_symptom_data['users'];
+					$data['correlations'] += $_symptom_data['correlations'];
 
-					foreach ($symptom_data['triggers'] as $triggerid => &$trigger) {
-						$trigger['dependencies'] = array_key_exists($triggerid, $db_triggers)
-							? $db_triggers[$triggerid]['dependencies']
-							: [];
+					foreach ($_symptom_data['actions'] as $key => $actions) {
+						$data['actions'][$key] += $actions;
 					}
-					unset($trigger);
 
-					// Add hosts from symptoms to the list.
-					$triggers_hosts += getTriggersHostsList($symptom_data['triggers']);
+					if ($_symptom_data['triggers']) {
+						$triggerids = array_keys($_symptom_data['triggers']);
 
-					// Store all known triggers in one place.
-					$data['triggers'] += $symptom_data['triggers'];
-				}
+						$db_triggers = API::Trigger()->get([
+							'output' => [],
+							'selectDependencies' => ['triggerid'],
+							'triggerids' => $triggerids,
+							'preservekeys' => true
+						]);
 
-				foreach ($data['problems'] as &$problem) {
-					foreach ($symptom_data['problems'] as $symptom) {
-						if (bccomp($symptom['cause_eventid'], $problem['eventid']) == 0) {
-							$problem['symptoms'][] = $symptom;
+						foreach ($_symptom_data['triggers'] as $triggerid => &$trigger) {
+							$trigger['dependencies'] = array_key_exists($triggerid, $db_triggers)
+								? $db_triggers[$triggerid]['dependencies']
+								: [];
+						}
+						unset($trigger);
+
+						// Add hosts from symptoms to the list.
+						$triggers_hosts += getTriggersHostsList($_symptom_data['triggers']);
+
+						// Store all known triggers in one place.
+						$data['triggers'] += $_symptom_data['triggers'];
+					}
+
+					foreach ($data['problems'] as &$problem) {
+						foreach ($_symptom_data['problems'] as $symptom) {
+							if (bccomp($symptom['cause_eventid'], $problem['eventid']) == 0) {
+								$problem['symptoms'][] = $symptom;
+							}
 						}
 					}
+					unset($problem);
+
+					// Combine symptom problems, to show tags later at some point.
+					$symptom_data['problems'] += $_symptom_data['problems'];
 				}
-				unset($problem);
 			}
 		}
 
@@ -1134,7 +1149,7 @@ class CScreenProblem extends CScreenBase {
 			];
 
 			// Add problems to table.
-			self::addProblemsToTable($table, $data['problems'], $data);
+			self::addProblemsToTable($table, $data['problems'], $data, false);
 
 			$footer = new CActionButtonList('action', 'eventids', [
 				'popup.acknowledge.edit' => [
@@ -1316,7 +1331,7 @@ class CScreenProblem extends CScreenBase {
 	 * @param array      $data['tags']                          List of tags.
 	 * @param bool       $nested                                If true, show the symptom rows with indentation.
 	 */
-	private static function addProblemsToTable(CTableInfo $table, array $problems, array $data, $nested = false): void {
+	private static function addProblemsToTable(CTableInfo $table, array $problems, array $data, $nested): void {
 		foreach ($problems as $problem) {
 			$trigger = $data['triggers'][$problem['objectid']];
 
@@ -1440,10 +1455,16 @@ class CScreenProblem extends CScreenBase {
 				? makeTriggerDependencies($data['dependencies'][$trigger['triggerid']])
 				: [];
 			$description[] = (new CLinkAction($problem['name']))
-				->setMenuPopup(CMenuPopupHelper::getTrigger($trigger['triggerid'], $problem['eventid'],
-					['show_rank_change_cause' => true, 'show_rank_change_symptom' => true]
-				))
-				->addClass(ZBX_STYLE_WORDBREAK);
+				->addClass(ZBX_STYLE_WORDBREAK)
+				->setMenuPopup(CMenuPopupHelper::getTrigger([
+					'triggerid' => $trigger['triggerid'],
+					'backurl' => (new CUrl('zabbix.php'))
+						->setArgument('action', 'problem.view')
+						->getUrl(),
+					'eventid' => $problem['eventid'],
+					'show_rank_change_cause' => true,
+					'show_rank_change_symptom' => true
+				]));
 
 			$opdata = null;
 
@@ -1607,7 +1628,7 @@ class CScreenProblem extends CScreenBase {
 
 			if ($data['show_timeline']) {
 				if ($data['last_clock'] != 0) {
-					self::addTimelineBreakpoint($table, $data, $problem, $nested);
+					self::addTimelineBreakpoint($table, $data, $problem, $nested, true);
 				}
 				$data['last_clock'] = $problem['clock'];
 
@@ -1760,7 +1781,7 @@ class CScreenProblem extends CScreenBase {
 		)));
 
 		if ($html) {
-			$hint_table = (new CTable())->addClass('list-table');
+			$hint_table = (new CTable())->addClass(ZBX_STYLE_LIST_TABLE);
 		}
 
 		foreach ($items as $itemid => $item) {
