@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -395,7 +395,7 @@
 
 						$(node).find('*[name]').each((_, input) => {
 							if (!$.isEmptyObject(input) && input.name != null) {
-								const regex = /items\[[\d+]\]\[([a-zA-Z0-9\-\_\.]+)\]/;
+								const regex = /items\[\d+\]\[([a-zA-Z0-9\-\_\.]+)\]/;
 								const name = input.name.match(regex);
 
 								short_fmt.push((name[1]).substr(0, 2) + ':' + input.value);
@@ -580,7 +580,7 @@
 
 				$('#items_' + i + '_name').attr('onclick', 'PopUp("popup.generic", ' +
 					'$.extend(' + JSON.stringify(parameters) + ', view.getOnlyHostParam()),' +
-					'{dialogue_class: "modal-popup-generic", trigger_element: this});'
+					'{dialogue_class: "modal-popup-generic", trigger_element: this.parentNode});'
 				);
 			}
 		},
@@ -611,37 +611,21 @@
 				$obj.attr('id', 'tmp' + $obj.attr('id'));
 			});
 
-			// Rewrite IDs to new order.
-			$('#itemsTable tr.sortable').each(function() {
-				const $obj = $(this);
+			for (const [index, row] of document.querySelectorAll('#itemsTable tr.sortable').entries()) {
+				row.id = row.id.substring(3).replace(/\d+/, `${index}`);
 
-				// Rewrite IDs in input fields.
-				$obj.find('*[id]').each(function() {
-					const $obj = $(this);
-					const id = $obj.attr('id').substring(3);
-					const part1 = id.substring(0, id.indexOf('items_') + 5);
-					let part2 = id.substring(id.indexOf('items_') + 6);
+				row.querySelectorAll('[id]').forEach(element => {
+					element.id = element.id.substring(3).replace(/\d+/, `${index}`);
 
-					part2 = part2.substring(part2.indexOf('_') + 1);
-
-					$obj.attr('id', part1 + '_' + i + '_' + part2);
-
-					// Set sortorder.
-					if (part2 === 'sortorder') {
-						$obj.val(i);
+					if (element.id.includes('sortorder')) {
+						element.value = index;
 					}
 				});
 
-				// Rewrite IDs in <tr>.
-				const id = $obj.attr('id').substring(3);
-				const part1 = id.substring(0, id.indexOf('items_') + 5);
-
-				$obj.attr('id', part1 + '_' + i);
-
-				i++;
-			});
-
-			i = 0;
+				row.querySelectorAll('[name]').forEach(element => {
+					element.name = element.name.replace(/\d+/, `${index}`);
+				});
+			}
 
 			$('#itemsTable tr.sortable').each(function() {
 				// Set row number.
@@ -673,12 +657,6 @@
 						$td.attr('width', $td.width())
 					}
 
-					// When dragging element on safari, it jumps out of the table.
-					if (SF) {
-						// Move back draggable element to proper position.
-						ui.css('left', (ui.offset().left - 2) + 'px');
-					}
-
 					return ui;
 				},
 				stop: (e, ui) => {
@@ -718,7 +696,7 @@
 		},
 
 		refresh() {
-			const url = new Curl('', false);
+			const url = new Curl('');
 			const form = document.getElementsByName(this.form_name)[0];
 			const fields = getFormFields(form);
 
@@ -751,7 +729,7 @@
 					}
 				}
 
-				const curl = new Curl('zabbix.php', false);
+				const curl = new Curl('zabbix.php');
 				curl.setArgument('action', 'host.list');
 
 				location.href = curl.getUrl();
