@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@
 
 	echo (new CListItem([
 		(new CDiv([
-			(new CDiv())->addClass(ZBX_STYLE_DRAG_ICON),
+			(new CDiv(new CVar('preprocessing[#{rowNum}][sortorder]', '#{sortorder}')))->addClass(ZBX_STYLE_DRAG_ICON),
 			(new CDiv($preproc_types_select))
 				->addClass('list-numbered-item')
 				->addClass('step-name'),
@@ -96,11 +96,11 @@
 </script>
 
 <script type="text/x-jquery-tmpl" id="preprocessing-steps-parameters-custom-width-chkbox-tmpl">
-	<?= (new CTextBox('preprocessing[#{rowNum}][params][0]', ''))
+	<?= (new CTextBox('preprocessing[#{rowNum}][params][0]', '#{value_0}'))
 			->setAttribute('placeholder', '#{placeholder_0}')
 			->setWidth('#{width_0}')
 			->setAttribute('maxlength', 1).
-		(new CTextBox('preprocessing[#{rowNum}][params][1]', ''))
+		(new CTextBox('preprocessing[#{rowNum}][params][1]', '#{value_1}'))
 			->setAttribute('placeholder', '#{placeholder_1}')
 			->setWidth('#{width_1}')
 			->setAttribute('maxlength', 1).
@@ -110,14 +110,151 @@
 	?>
 </script>
 
+<script type="text/x-jquery-tmpl" id="preprocessing-steps-parameters-custom-prometheus-pattern-tmpl">
+	<?= (new CTextBox('preprocessing[#{rowNum}][params][0]', ''))
+			->setAttribute('placeholder', '#{placeholder_0}').
+		(new CSelect('preprocessing[#{rowNum}][params][1]'))
+			->addOptions(CSelect::createOptionsFromArray([
+				ZBX_PREPROC_PROMETHEUS_VALUE => _('value'),
+				ZBX_PREPROC_PROMETHEUS_LABEL => _('label'),
+				ZBX_PREPROC_PROMETHEUS_SUM => 'sum',
+				ZBX_PREPROC_PROMETHEUS_MIN => 'min',
+				ZBX_PREPROC_PROMETHEUS_MAX => 'max',
+				ZBX_PREPROC_PROMETHEUS_AVG => 'avg',
+				ZBX_PREPROC_PROMETHEUS_COUNT => 'count'
+			]))
+			->addClass('js-preproc-param-prometheus-pattern-function').
+		(new CTextBox('preprocessing[#{rowNum}][params][2]', ''))
+			->setAttribute('placeholder', '#{placeholder_2}')
+			->setEnabled(false)
+	?>
+</script>
+
+<script type="text/x-jquery-tmpl" id="preprocessing-steps-parameters-snmp-walk-value-tmpl">
+	<?= (new CTextBox('preprocessing[#{rowNum}][params][0]', ''))->setAttribute('placeholder', _('OID')).
+		(new CSelect('preprocessing[#{rowNum}][params][1]'))
+			->setValue(ZBX_PREPROC_SNMP_UNCHANGED)
+			->setAdaptiveWidth(202)
+			->addOptions([
+				new CSelectOption(ZBX_PREPROC_SNMP_UNCHANGED, _('Unchanged')),
+				new CSelectOption(ZBX_PREPROC_SNMP_UTF8_FROM_HEX, _('UTF-8 from Hex-STRING')),
+				new CSelectOption(ZBX_PREPROC_SNMP_MAC_FROM_HEX, _('MAC from Hex-STRING')),
+				new CSelectOption(ZBX_PREPROC_SNMP_INT_FROM_BITS, _('Integer from BITS'))
+			])
+	?>
+</script>
+
+<script type="text/x-jquery-tmpl" id="preprocessing-steps-parameters-snmp-walk-to-json-tmpl">
+	<?php
+		echo (new CDiv(
+				(new CTable())
+					->addClass('group-json-mapping')
+					->setHeader(
+						(new CRowHeader([
+							new CColHeader(_('Field name')),
+							new CColHeader(_('OID prefix')),
+							new CColHeader(_('Format')),
+							(new CColHeader(_('Action')))->addClass(ZBX_STYLE_NOWRAP)
+						]))->addClass(ZBX_STYLE_GREY)
+					)
+					->addItem(
+						(new CRow([
+							new CCol(
+								(new CTextBox('preprocessing[#{rowNum}][params][]', ''))
+									->removeId()
+									->setAttribute('placeholder', _('Field name'))
+							),
+							new CCol(
+								(new CTextBox('preprocessing[#{rowNum}][params][]', ''))
+									->removeId()
+									->setAttribute('placeholder', _('OID prefix'))
+							),
+							new CCol(
+								(new CSelect('preprocessing[#{rowNum}][params][]'))
+									->setValue(ZBX_PREPROC_SNMP_UNCHANGED)
+									->setWidth(ZBX_TEXTAREA_PREPROC_TREAT_SELECT)
+									->addOptions([
+										new CSelectOption(ZBX_PREPROC_SNMP_UNCHANGED, _('Unchanged')),
+										new CSelectOption(ZBX_PREPROC_SNMP_UTF8_FROM_HEX, _('UTF-8 from Hex-STRING')),
+										new CSelectOption(ZBX_PREPROC_SNMP_MAC_FROM_HEX, _('MAC from Hex-STRING')),
+										new CSelectOption(ZBX_PREPROC_SNMP_INT_FROM_BITS, _('Integer from BITS'))
+									])
+							),
+							(new CCol(
+								(new CSimpleButton(_('Remove')))
+									->addClass(ZBX_STYLE_BTN_LINK)
+									->addClass('js-group-json-action-delete')
+									->setEnabled(false)
+							))->addClass(ZBX_STYLE_NOWRAP)
+						]))->addClass('group-json-row')
+					)
+					->addItem(
+						(new CTag('tfoot', true))
+							->addItem(
+								(new CCol(
+									(new CSimpleButton(_('Add')))
+										->addClass(ZBX_STYLE_BTN_LINK)
+										->addClass('js-group-json-action-add')
+								))->setColSpan(4)
+							)
+					)
+					->setAttribute('data-index', '#{rowNum}')
+			))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR);
+	?>
+</script>
+
+<script type="text/x-jquery-tmpl" id="preprocessing-steps-parameters-snmp-walk-to-json-row-tmpl">
+	<?php
+		echo (new CRow([
+			new CCol(
+				(new CTextBox('preprocessing[#{rowNum}][params][]', ''))
+					->removeId()
+					->setAttribute('placeholder', _('Field name'))
+			),
+			new CCol(
+				(new CTextBox('preprocessing[#{rowNum}][params][]', ''))
+					->removeId()
+					->setAttribute('placeholder', _('OID prefix'))
+			),
+			new CCol(
+				(new CSelect('preprocessing[#{rowNum}][params][]'))
+					->setValue(ZBX_PREPROC_SNMP_UNCHANGED)
+					->setWidth(ZBX_TEXTAREA_PREPROC_TREAT_SELECT)
+					->addOptions([
+						new CSelectOption(ZBX_PREPROC_SNMP_UNCHANGED, _('Unchanged')),
+						new CSelectOption(ZBX_PREPROC_SNMP_UTF8_FROM_HEX, _('UTF-8 from Hex-STRING')),
+						new CSelectOption(ZBX_PREPROC_SNMP_MAC_FROM_HEX, _('MAC from Hex-STRING')),
+						new CSelectOption(ZBX_PREPROC_SNMP_INT_FROM_BITS, _('Integer from BITS'))
+					])
+			),
+			(new CCol(
+				(new CSimpleButton(_('Remove')))
+					->addClass(ZBX_STYLE_BTN_LINK)
+					->addClass('js-group-json-action-delete')
+			))->addClass(ZBX_STYLE_NOWRAP)
+		]))->addClass('group-json-row');
+	?>
+</script>
+
 <script type="text/javascript">
 	jQuery(function($) {
 		function makeParameterInput(index, type) {
-			var preproc_param_single_tmpl = new Template($('#preprocessing-steps-parameters-single-tmpl').html()),
-				preproc_param_double_tmpl = new Template($('#preprocessing-steps-parameters-double-tmpl').html()),
-				preproc_param_custom_width_chkbox_tmpl =
-					new Template($('#preprocessing-steps-parameters-custom-width-chkbox-tmpl').html()),
-				preproc_param_multiline_tmpl = new Template($('#preprocessing-steps-parameters-multiline-tmpl').html());
+			const preproc_param_single_tmpl = new Template($('#preprocessing-steps-parameters-single-tmpl').html());
+			const preproc_param_double_tmpl = new Template($('#preprocessing-steps-parameters-double-tmpl').html());
+			const preproc_param_custom_width_chkbox_tmpl =
+				new Template($('#preprocessing-steps-parameters-custom-width-chkbox-tmpl').html());
+			const preproc_param_multiline_tmpl = new Template(
+				$('#preprocessing-steps-parameters-multiline-tmpl').html()
+			);
+			const preproc_param_prometheus_pattern_tmpl = new Template(
+				$('#preprocessing-steps-parameters-custom-prometheus-pattern-tmpl').html()
+			);
+			const preproc_param_snmp_walk_value_tmpl = new Template(
+				$('#preprocessing-steps-parameters-snmp-walk-value-tmpl').html()
+			);
+			const preproc_param_snmp_walk_to_json_tmpl = new Template(
+				$('#preprocessing-steps-parameters-snmp-walk-to-json-tmpl').html()
+			);
 
 			switch (type) {
 				case '<?= ZBX_PREPROC_MULTIPLIER ?>':
@@ -185,16 +322,16 @@
 						label_after: '}',
 						grow: 'auto',
 						rows: 0,
-						maxlength: <?= (int) DB::getFieldLength('item_preproc', 'params') ?>
+						maxlength: <?= DB::getFieldLength('item_preproc', 'params') ?>
 					});
 
 				case '<?= ZBX_PREPROC_PROMETHEUS_PATTERN ?>':
-					return $(preproc_param_double_tmpl.evaluate({
+					return $(preproc_param_prometheus_pattern_tmpl.evaluate({
 						rowNum: index,
 						placeholder_0: <?= json_encode(
 							_('<metric name>{<label name>="<label value>", ...} == <value>')
 						) ?>,
-						placeholder_1: <?= json_encode(_('<label name>')) ?>
+						placeholder_2: <?= json_encode(_('<label name>')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_PROMETHEUS_TO_JSON ?>':
@@ -210,8 +347,10 @@
 						rowNum: index,
 						width_0: <?= ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH ?>,
 						width_1: <?= ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH ?>,
-						placeholder_0: ',',
-						placeholder_1: '"',
+						placeholder_0: <?= json_encode(_('delimiter')) ?>,
+						value_0: ',',
+						placeholder_1: <?= json_encode(_('qualifier')) ?>,
+						value_1: '"',
 						chkbox_label: <?= json_encode(_('With header row')) ?>,
 						chkbox_value: <?= ZBX_PREPROC_CSV_HEADER ?>,
 						chkbox_default: true
@@ -224,6 +363,16 @@
 						placeholder_1: <?= json_encode(_('replacement')) ?>
 					}));
 
+				case '<?= ZBX_PREPROC_SNMP_WALK_VALUE ?>':
+					return $(preproc_param_snmp_walk_value_tmpl.evaluate({
+						rowNum: index,
+					}));
+
+				case '<?= ZBX_PREPROC_SNMP_WALK_TO_JSON ?>':
+					return $(preproc_param_snmp_walk_to_json_tmpl.evaluate({
+						rowNum: index
+					}));
+
 				default:
 					return '';
 			}
@@ -258,7 +407,7 @@
 		var $preprocessing = $('#preprocessing');
 
 		if ($preprocessing.length === 0) {
-			const prep_elem = document.querySelector('#preprocessing_div');
+			const prep_elem = document.querySelector('#preprocessing-field');
 
 			if (!prep_elem) {
 				return false;
@@ -272,7 +421,7 @@
 			$preprocessing = $(obj.querySelector('#preprocessing'));
 		}
 
-		var step_index = $preprocessing.find('li.sortable').length;
+		let step_index = $preprocessing.find('li.sortable').length;
 
 		$preprocessing.sortable({
 			disabled: $preprocessing.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').hasClass('<?= ZBX_STYLE_DISABLED ?>'),
@@ -282,22 +431,33 @@
 			cursor: 'grabbing',
 			handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
 			tolerance: 'pointer',
-			opacity: 0.6
+			opacity: 0.6,
+			update: function() {
+				let i = 0;
+
+				$(this).find('li.sortable').each(function() {
+					$(this).find('[name*="sortorder"]').val(i++);
+				});
+			}
 		});
 
+		const change_event = new CustomEvent('item.preprocessing.change');
+
 		$preprocessing
 			.on('click', '.element-table-add', function() {
-				var preproc_row_tmpl = new Template($('#preprocessing-steps-tmpl').html()),
-					$row = $(preproc_row_tmpl.evaluate({rowNum: step_index}));
-					type = $('z-select[name*="type"]', $row).val();
+				let sortable_count = $preprocessing.find('li.sortable').length;
+				const preproc_row_tmpl = new Template($('#preprocessing-steps-tmpl').html());
+				const $row = $(preproc_row_tmpl.evaluate({
+					rowNum: step_index,
+					sortorder: sortable_count++
+				}));
+				const type = $('z-select[name*="type"]', $row).val();
 
 				$('.step-parameters', $row).html(makeParameterInput(step_index, type));
 				$(this).closest('.preprocessing-list-foot').before($row);
 
 				$('.preprocessing-list-head').show();
 
-				var sortable_count = $preprocessing.find('li.sortable').length;
-
 				if (sortable_count == 1) {
 					$('#preproc_test_all').show();
 					$preprocessing
@@ -312,6 +472,7 @@
 						.removeClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
 
+				$preprocessing[0].dispatchEvent(change_event);
 				updateTypeOptionsAvailability();
 				step_index++;
 			})
@@ -334,7 +495,7 @@
 			.on('click', '.element-table-remove', function() {
 				$(this).closest('li.sortable').remove();
 
-				var sortable_count = $preprocessing.find('li.sortable').length;
+				const sortable_count = $preprocessing.find('li.sortable').length;
 
 				if (sortable_count == 0) {
 					$('#preproc_test_all').hide();
@@ -346,6 +507,15 @@
 						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').addClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
 
+				if (sortable_count > 0) {
+					let i = 0;
+
+					$preprocessing.find('li.sortable').each(function() {
+						$(this).find('[name*="sortorder"]').val(i++);
+					});
+				}
+
+				$preprocessing[0].dispatchEvent(change_event);
 				updateTypeOptionsAvailability();
 			})
 			.on('change', 'z-select[name*="type"]', function() {
@@ -422,6 +592,42 @@
 						.attr('placeholder', <?= json_encode(_('error message')) ?>)
 						.show();
 				}
+			})
+			.on('change', '.js-preproc-param-prometheus-pattern-function', function() {
+				$(this).next('input').prop('disabled', $(this).val() !== '<?= ZBX_PREPROC_PROMETHEUS_LABEL ?>');
+			})
+			.on('click', '.js-group-json-action-delete', function() {
+				const table = this.closest('.group-json-mapping');
+				const row = this.closest('.group-json-row');
+				const count = table.querySelectorAll('.group-json-row').length;
+
+				if (count == 1) {
+					return;
+				}
+
+				row.remove();
+
+				if (count == 2) {
+					table.querySelector('.js-group-json-action-delete').disabled = true;
+				}
+			})
+			.on('click', '.js-group-json-action-add', function() {
+				const template = new Template(
+					document
+						.getElementById('preprocessing-steps-parameters-snmp-walk-to-json-row-tmpl')
+						.innerHTML
+				);
+				const container = this.closest('.group-json-mapping');
+
+				const row_numb = container.dataset.index;
+
+				[...container.querySelectorAll('.js-group-json-action-delete')].map((btn) => {
+					btn.disabled = false;
+				});
+
+				container
+					.querySelector('tbody')
+					.insertAdjacentHTML('beforeend', template.evaluate({rowNum: row_numb}));
 			});
 	});
 </script>
